@@ -10,6 +10,7 @@
 #define HAVE_EXPLICIT_BZERO 1
 #define HAVE_EXPLICIT_MEMSET 0
 #define HAVE_CLOCK_NANOSLEEP 0
+#define HAVE_SIGACTION 1
 
 #ifdef R_MESON_VERSION
 #define R2_PREFIX "/usr/local"
@@ -28,7 +29,7 @@
 #define R2_FLAGS "@FLAGS@"
 #define R2_HUD "@HUD@"
 #else
-#if __WINDOWS__ || _MSC_VER || CUTTER
+#if __WINDOWS__ || _MSC_VER
 #define R2_PREFIX "."
 #define R2_LIBDIR "lib"
 #define R2_INCDIR "include\\libr"
@@ -97,6 +98,8 @@
 #define USE_PTRACE_WRAP 0
 #define HAVE_FORK 1
 
+#define USE_TREESITTER 0
+
 #define WITH_GPL 1
 
 #if __APPLE__ && __POWERPC__
